@@ -1,17 +1,21 @@
-function insert_version_links() {
-    var labels = ['dev', '0.8.0', '0.7.0', '0.6', '0.5', '0.4', '0.3'];
+var versions = ['dev', '0.9.x', '0.8.0', '0.7.0', '0.6', '0.5', '0.4', '0.3'];
 
-    for (i = 0; i < labels.length; i++){
+function insert_version_links() {
+    for (i = 0; i < versions.length; i++){
         open_list = '<li>'
         if (typeof(DOCUMENTATION_OPTIONS) !== 'undefined') {
-            if ((DOCUMENTATION_OPTIONS['VERSION'] == labels[i]) ||
+            if ((DOCUMENTATION_OPTIONS['VERSION'] == versions[i]) ||
                 (DOCUMENTATION_OPTIONS['VERSION'].match(/dev$/) && (i == 0))) {
                 open_list = '<li id="current">'
             }
         }
         document.write(open_list);
         document.write('<a href="URL">skimage VERSION</a> </li>\n'
-                        .replace('VERSION', labels[i])
-                        .replace('URL', 'http://scikit-image.org/docs/' + labels[i]));
+                        .replace('VERSION', versions[i])
+                        .replace('URL', 'http://scikit-image.org/docs/' + versions[i]));
     }
 }
+
+function stable_version() {
+    return versions[1];
+}
