@@ -13,11 +13,17 @@ def configuration(parent_package='', top_path=None):
     config.add_data_dir('tests')
 
     cython(['corner_cy.pyx'], working_path=base_path)
+    cython(['censure_cy.pyx'], working_path=base_path)
+    cython(['_brief_cy.pyx'], working_path=base_path)
     cython(['_texture.pyx'], working_path=base_path)
     cython(['_template.pyx'], working_path=base_path)
 
     config.add_extension('corner_cy', sources=['corner_cy.c'],
                          include_dirs=[get_numpy_include_dirs()])
+    config.add_extension('censure_cy', sources=['censure_cy.c'],
+                         include_dirs=[get_numpy_include_dirs()])
+    config.add_extension('_brief_cy', sources=['_brief_cy.c'],
+                         include_dirs=[get_numpy_include_dirs()])
     config.add_extension('_texture', sources=['_texture.c'],
                          include_dirs=[get_numpy_include_dirs(), '../_shared'])
     config.add_extension('_template', sources=['_template.c'],
